@@ -1,21 +1,22 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300020';
+$Email::Sender::Transport::SMTP::VERSION = '1.300027';
 use Moo;
 
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
 use Email::Sender::Role::HasMessage ();
 use Email::Sender::Util;
-use MooX::Types::MooseLike::Base qw(Bool Int Str);
+use MooX::Types::MooseLike::Base qw(Bool Int Str HashRef);
+use Net::SMTP 3.07; # SSL support, fixed datasend
 
 use utf8 (); # See below. -- rjbs, 2015-05-14
 
 #pod =head1 DESCRIPTION
 #pod
 #pod This transport is used to send email over SMTP, either with or without secure
-#pod sockets (SSL).  It is one of the most complex transports available, capable of
-#pod partial success.
+#pod sockets (SSL/TLS).  It is one of the most complex transports available, capable
+#pod of partial success.
 #pod
 #pod For a potentially more efficient version of this transport, see
 #pod L<Email::Sender::Transport::SMTP::Persistent>.
@@ -28,9 +29,15 @@ use utf8 (); # See below. -- rjbs, 2015-05-14
 #pod
 #pod =item C<host>: the name of the host to connect to; defaults to C<localhost>
 #pod
-#pod =item C<ssl>: if true, connect via SSL; defaults to false
+#pod =item C<ssl>: if 'starttls', use STARTTLS; if 'ssl' (or 1), connect securely;
+#pod otherwise, no security
 #pod
-#pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for SSL
+#pod =item C<ssl_options>: passed to Net::SMTP constructor for 'ssl' connections or
+#pod to starttls for 'starttls' connections; should contain extra options for
+#pod IO::Socket::SSL
+#pod
+#pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl',
+#pod 587 for 'starttls'
 #pod
 #pod =item C<timeout>: maximum time in secs to wait for server; default is 120
 #pod
@@ -42,13 +49,37 @@ sub BUILD {
     if $self->host =~ /:/;
 }
 
-has host => (is => 'ro', isa => Str,  default => sub { 'localhost' });
-has ssl  => (is => 'ro', isa => Bool, default => sub { 0 });
+has host => (is => 'ro', isa => Str, default => sub { 'localhost' });
+has ssl  => (is => 'ro', isa => Str, default => sub { 0 });
+
+has _security => (
+  is   => 'ro',
+  lazy => 1,
+  init_arg => undef,
+  default  => sub {
+    my $ssl = $_[0]->ssl;
+    return '' unless $ssl;
+    $ssl = lc $ssl;
+    return 'starttls' if 'starttls' eq $ssl;
+    return 'ssl' if $ssl eq 1 or $ssl eq 'ssl';
+
+    Carp::cluck(qq{true "ssl" argument to Email::Sender::Transport::SMTP should be 'ssl' or 'startls' or '1' but got '$ssl'});
+
+    return 1;
+  },
+);
+
+has ssl_options => (is => 'ro', isa => HashRef, default => sub {  {}  });
+
 has port => (
   is  => 'ro',
   isa => Int,
   lazy    => 1,
-  default => sub { return $_[0]->ssl ? 465 : 25; },
+  default => sub {
+    return $_[0]->_security eq 'starttls' ? 587
+         : $_[0]->_security eq 'ssl'      ? 465
+         :                                   25
+  },
 );
 
 has timeout => (is => 'ro', isa => Int, default => sub { 120 });
@@ -104,16 +135,21 @@ sub _smtp_client {
   my ($self) = @_;
 
   my $class = "Net::SMTP";
-  if ($self->ssl) {
-    require Net::SMTP::SSL;
-    $class = "Net::SMTP::SSL";
-  } else {
-    require Net::SMTP;
-  }
 
   my $smtp = $class->new( $self->_net_smtp_args );
 
-  $self->_throw("unable to establish SMTP connection") unless $smtp;
+  unless ($smtp) {
+    $self->_throw(
+      sprintf "unable to establish SMTP connection to %s port %s",
+        $self->host,
+        $self->port,
+    );
+  }
+
+  if ($self->_security eq 'starttls') {
+    $self->_throw("can't STARTTLS: " . $smtp->message)
+      unless $smtp->starttls(%{ $self->ssl_options });
+  }
 
   if ($self->sasl_username) {
     $self->_throw("sasl_username but no sasl_password")
@@ -139,6 +175,11 @@ sub _net_smtp_args {
     Port    => $self->port,
     Timeout => $self->timeout,
     Debug   => $self->debug,
+
+    (($self->_security eq 'ssl')
+      ? (SSL => 1, %{ $self->ssl_options })
+      : ()),
+
     defined $self->helo      ? (Hello     => $self->helo)      : (),
     defined $self->localaddr ? (LocalAddr => $self->localaddr) : (),
     defined $self->localport ? (LocalPort => $self->localport) : (),
@@ -280,13 +321,13 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300020
+version 1.300027
 
 =head1 DESCRIPTION
 
 This transport is used to send email over SMTP, either with or without secure
-sockets (SSL).  It is one of the most complex transports available, capable of
-partial success.
+sockets (SSL/TLS).  It is one of the most complex transports available, capable
+of partial success.
 
 For a potentially more efficient version of this transport, see
 L<Email::Sender::Transport::SMTP::Persistent>.
@@ -299,9 +340,15 @@ The following attributes may be passed to the constructor:
 
 =item C<host>: the name of the host to connect to; defaults to C<localhost>
 
-=item C<ssl>: if true, connect via SSL; defaults to false
+=item C<ssl>: if 'starttls', use STARTTLS; if 'ssl' (or 1), connect securely;
+otherwise, no security
 
-=item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for SSL
+=item C<ssl_options>: passed to Net::SMTP constructor for 'ssl' connections or
+to starttls for 'starttls' connections; should contain extra options for
+IO::Socket::SSL
+
+=item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl',
+587 for 'starttls'
 
 =item C<timeout>: maximum time in secs to wait for server; default is 120
 
@@ -333,7 +380,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
