@@ -1,6 +1,6 @@
 package Email::Sender::Transport::Sendmail;
 # ABSTRACT: send mail via sendmail(1)
-$Email::Sender::Transport::Sendmail::VERSION = '1.300014';
+$Email::Sender::Transport::Sendmail::VERSION = '1.300027';
 use Moo;
 with 'Email::Sender::Transport';
 
@@ -88,7 +88,7 @@ sub send_email {
   my $string = $email->as_string;
   $string =~ s/\x0D\x0A/\x0A/g unless $^O eq 'MSWin32';
 
-  print $pipe $email->as_string
+  print $pipe $string
     or Email::Sender::Failure->throw("couldn't send message to sendmail: $!");
 
   close $pipe
@@ -112,7 +112,7 @@ Email::Sender::Transport::Sendmail - send mail via sendmail(1)
 
 =head1 VERSION
 
-version 1.300014
+version 1.300027
 
 =head2 DESCRIPTION
 
@@ -131,7 +131,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
